ScreenConfig class

Constructors

ScreenConfig({required String endpoint, required String icon, required String hoveredIcon, required String tabTitle, String? pageTitle})

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
hoveredIcon String
final
icon String
final
pageTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabTitle String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited