JsBridge class

Constructors

JsBridge()

Properties

buttons List<ButtonConfig>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerBridge(WebViewController controller, BuildContext context, WebViewCookieManager cookieManager) → void
sendToFlutter(Map<String, dynamic> params, BuildContext context, WebViewCookieManager cookieManager) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited