AppPreferences class

Class to manage shared preferences with generic methods.

Constructors

AppPreferences()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearAll() Future<void>
Clears all values from shared preferences.
getValue<T>(String key) Future<T?>
Retrieves a value of generic type T from shared preferences.
removeValue(String key) Future<void>
Removes a value from shared preferences.
saveValue<T>(String key, T value) Future<void>
Saves a value of generic type T to shared preferences.