PreferenceKeyExtension extension
Extension on PreferenceKey to get the string value of the enum.
Properties
- keyString → String
-
Available on PreferenceKey, provided by the PreferenceKeyExtension extension
no setter
Extension on PreferenceKey to get the string value of the enum.
Available on PreferenceKey, provided by the PreferenceKeyExtension extension