BridgeCommand enum
Values
- pop → const BridgeCommand
- popRoot → const BridgeCommand
- push → const BridgeCommand
- popAndPush → const BridgeCommand
- popRootAndPush → const BridgeCommand
- closeAndAlert → const BridgeCommand
- getToken → const BridgeCommand
- setToken → const BridgeCommand
- deleteToken → const BridgeCommand
- refresh → const BridgeCommand
- saveLocally → const BridgeCommand
- getLocally → const BridgeCommand
- deleteLocally → const BridgeCommand
- clearAll → const BridgeCommand
- unknown → const BridgeCommand
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String command) → BridgeCommand
Constants
-
values
→ const List<
BridgeCommand> - A constant List of the values in this enum, in order of their declaration.